@@ -16,7 +16,7 @@ from PyQt5.QtCore import pyqtSlot, pyqtSignal, Qt, QPoint, QEvent
 from PyQt5.QtGui import QColor, QKeySequence, QTextCursor, QBrush
 from PyQt5.QtWidgets import (
     QWidget, QMenu, QApplication, QHBoxLayout, QSpacerItem, QSizePolicy,
-    QTextEdit, QToolButton
+    QTextEdit, QToolButton, QDialog
 )
 
 from E5Gui.E5ZoomWidget import E5ZoomWidget
@@ -295,7 +295,7 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         self.deviceInfoLabel.clear()
         
         self.deviceTypeComboBox.addItem("", "")
-        devices = MicroPythonDevices.getFoundDevices()
+        devices, unknownDevices = MicroPythonDevices.getFoundDevices()
         if devices:
             self.deviceInfoLabel.setText(
                 self.tr("%n supported device(s) detected.", "", len(devices)))
@@ -325,6 +325,39 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         
         self.on_deviceTypeComboBox_activated(index)
         self.deviceTypeComboBox.setCurrentIndex(index)
+        
+        if unknownDevices:
+            ignoredUnknown = {
+                tuple(d)
+                for d in Preferences.getMicroPython("IgnoredUnknownDevices")
+            }
+            newUnknownDevices = set(unknownDevices) - ignoredUnknown
+            if newUnknownDevices:
+                button = E5MessageBox.information(
+                    self,
+                    self.tr("Unknown MicroPython Device"),
+                    self.tr(
+                        '<p>Detected these unknown serial devices</p>'
+                        '<ul>'
+                        '<li>{0}</li>'
+                        '</ul>'
+                        '<p>Please report them together with the board name'
+                        ' and a short description to <a href="mailto:'
+                        'eric-bugs@eric-ide.python-projects.org"> the eric'
+                        ' bug reporting address</a> if it is a MicroPython'
+                        ' board.</p>'
+                    ).format("</li><li>".join([
+                        self.tr("{0} ({1:04x}/{2:04x})").format(desc, vid, pid)
+                        for vid, pid, desc in newUnknownDevices])),
+                    E5MessageBox.StandardButtons(
+                        E5MessageBox.Ignore |
+                        E5MessageBox.Ok
+                    )
+                )
+                if button == E5MessageBox.Ignore:
+                    ignoredUnknown = list(ignoredUnknown | newUnknownDevices)
+                    Preferences.setMicroPython("IgnoredUnknownDevices",
+                                               ignoredUnknown)
     
     def __handlePreferencesChanged(self):
         """
@@ -1175,6 +1208,9 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
                 self.tr("Show Documentation"), self.__showDocumentation)
             act.setEnabled(self.__device.hasDocumentationUrl())
         self.__superMenu.addSeparator()
+        self.__superMenu.addAction(self.tr("Ignored Serial Devices"),
+                                   self.__manageIgnored)
+        self.__superMenu.addSeparator()
         self.__superMenu.addAction(self.tr("Configure"), self.__configure)
     
     @pyqtSlot()
@@ -1507,6 +1543,22 @@ class MicroPythonWidget(QWidget, Ui_MicroPythonWidget):
         url = self.__device.getFirmwareUrl()
         e5App().getObject("UserInterface").launchHelpViewer(url)
     
+    @pyqtSlot()
+    def __manageIgnored(self):
+        """
+        Private slot to manage the list of ignored serial devices.
+        """
+        # TODO: implement this
+        from .IgnoredDevicesDialog import IgnoredDevicesDialog
+        
+        dlg = IgnoredDevicesDialog(
+            Preferences.getMicroPython("IgnoredUnknownDevices"),
+            self)
+        if dlg.exec_() == QDialog.Accepted:
+            ignoredDevices = dlg.getDevices()
+            Preferences.setMicroPython("IgnoredUnknownDevices",
+                                       ignoredDevices)
+    
     @pyqtSlot()
     def __configure(self):
         """
